Welcome to Tradenity Django framework SDK extensions.
==========

This extension library facilitates integration between Django applications and [Python SDK](https://github.com/tradenity/python-sdk) for [Tradenity ecommerce API](https://www.tradenity.com).

## Installation

This package is available through PyPI (Python Package Index), to install it type the following on the command line:

    $ pip install tradenity-django-ext

Or, add this line to your application's requirements.txt:

```python
tradenity-django-ext==0.7.0
```

And then execute:

    $ pip install -r requirements.txt



## Documentation

Detailed documentation can be found on our [knowledge base site:](http://docs.tradenity.com/kb/sdk/python/)



## Contributing

1. Fork it ( https://github.com/tradenity/python-sdk-django-ext/fork )
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request
